
## for tidyverse (magrittr & dplyr) functions 
if (getRversion() >= "2.15.1"){
  utils::globalVariables(c('GT', 'clone', 'isTip', 'y', 'label', 'cell', 'mut', 'p', 'reorder', 'edges',
   'nodes', 'n_mut', 'node', 'leaf', 'node_phylo', 'name', 'site', 'l', 'last_mut', 'from_label', 'to_label', '.', 'id'))
}






